// Persistence of Vision Ray Tracer Scene Description File
// File: ?.pov
// Vers: 3.6
// Desc: Basic Scene Example
// Date: mm/dd/yy
// Auth: ?
//

#version unofficial megapov 1.21;

#include "colors.inc"  
#include "FindAffine.inc" 
#include "iso_csg.inc" 
#include "textures.inc" 
#include "mechsim.inc"    

Set_Debug( true )

#declare R1 = seed( 411411 );

#declare p0 = <rand(R1)-0.5, rand(R1)-0.5, rand(R1)-0.5>;
#declare p1 = <rand(R1)-0.5, rand(R1)-0.5, rand(R1)-0.5>;
#declare p2 = <rand(R1)-0.5, rand(R1)-0.5, rand(R1)-0.5>; 

#declare Use_Affine = true;

global_settings {
  assumed_gamma 1.0
}

global_settings {
  assumed_gamma 1.0
  
  mechsim {
    gravity <0, -9.81, 0>
    method 1
    
    environment {
      IC_Plane(y,-1)
      stiffness 60000
      damping 9000
      friction 0.01, 1.001
    }
    
    collision {
      1
      stiffness 60000
      damping 4000
    } 
  
    #if( frame_number != 1 )
      step_count 600
      time_step (1/30)/600 
      
      topology {  
        load_file "test.dat"  
              
        save_file "test.dat" 
      }
    #else
      step_count 0
    
      topology {  
        mass { p0, 0, 0.04 density 32000 }
        mass { p1, 0, 0.04 density 32000 }
        mass { p2, 0, 0.04 density 32000 }
        connection { 0, 1 stiffness 1600 damping 2000 }
        connection { 1, 2 stiffness 1600 damping 2000 }
        connection { 2, 0 stiffness 1600 damping 2000 }
        face { 0, 1, 2 }
        
        save_file "test.dat"  
      }
    #end
  }
}  

#if( Use_Affine )   
  // texture is "attached" to triangle
  #if( frame_number = 1 )
    triangle {
      p0, p1, p2
    
      pigment { Jade }
    } 
  #else
    #declare q0 = mechsim:mass(0):position;
    #declare q1 = mechsim:mass(1):position;
    #declare q2 = mechsim:mass(2):position;  
  
    #declare M = array[ 3 ][ 3 ]; 
    #declare p3 = <0,0,0>;
    #declare q3 = <0,0,0>;
    FindAffine( p0, p1, p2, p3, q0, q1, q2, q3, M )

    triangle {
      q0, q1, q2
    
      pigment {
        Jade 
      
        translate -p0     
        matrix <M[ 0 ][ 0 ], M[ 1 ][ 0 ], M[ 2 ][ 0 ],
                M[ 0 ][ 1 ], M[ 1 ][ 1 ], M[ 2 ][ 1 ],
                M[ 0 ][ 2 ], M[ 1 ][ 2 ], M[ 2 ][ 2 ],
                q0.x, q0.y, q0.z>
      }
    }
  #end
#else 
  // triangle falls "through" texture
  triangle {
    q0, q1, q2
    
    pigment { Jade }
  } 
#end

// ----------------------------------------

camera {
  location  <0.0, 0, -3.0>
  direction 1*z
  right     x*image_width/image_height
  look_at   <0.0, 0.0,  0.0>
}

light_source {
  <0, 0, 0>            // light's position (translated below)
  color rgb <1, 1, 1>  // light's color
  translate <-30, 30, -30>
}

// ----------------------------------------

plane { y, -1.0
  pigment {
    checker
      color rgb 1
      color rgb 0
  }
}